pub struct Agent { /* private fields */ }Expand description
Agent handle for controlling async actor (NOT Clone)
Implementations
Sourceimpl Agent
Agent implementation
impl Agent
Agent implementation
Sourcepub fn new(
task: &str,
add_infos: &str,
mcp_client: Arc<KodegenClient>,
prompts: PromptConfig,
max_actions_per_step: usize,
agent_state: Arc<Mutex<AgentState>>,
config: AgentConfig,
) -> AgentResult<Self>
pub fn new( task: &str, add_infos: &str, mcp_client: Arc<KodegenClient>, prompts: PromptConfig, max_actions_per_step: usize, agent_state: Arc<Mutex<AgentState>>, config: AgentConfig, ) -> AgentResult<Self>
Create a new agent instance
Sourcepub async fn run(&self, max_steps: usize) -> AgentResult<AgentHistoryList>
pub async fn run(&self, max_steps: usize) -> AgentResult<AgentHistoryList>
Run the agent to perform a task with a maximum number of steps
Sourcepub async fn stop(&self) -> AgentResult<()>
pub async fn stop(&self) -> AgentResult<()>
Gracefully shut down the agent processor
Sends Stop command and waits for processor to confirm shutdown. Returns when processor has fully stopped and cleaned up resources.
Errors
AgentError::ChannelClosed: Command channel already closed (processor dead)AgentError::UnexpectedError: Processor didn’t respond within timeoutAgentError::UnexpectedError: Processor sent unexpected response
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Check if agent processor is still running
Returns true if the processor task is active and accepting commands.
Returns false if the processor has stopped (command channel closed).
This is useful for:
- Checking processor state before sending commands
- Polling for processor completion
- Debugging processor lifecycle